Array manipulation routines
***************************

.. currentmodule:: numpy

Basic operations
================
.. autosummary::
   :toctree: generated/

    copyto

Changing array shape
====================
.. autosummary::
   :toctree: generated/


   reshape
   ravel
   ndarray.flat
   ndarray.flatten

Transpose-like operations
=========================
.. autosummary::
   :toctree: generated/

   rollaxis
   swapaxes
   ndarray.T
   transpose

Changing number of dimensions
=============================
.. autosummary::
   :toctree: generated/

   atleast_1d
   atleast_2d
   atleast_3d
   broadcast
   broadcast_to
   broadcast_arrays
   expand_dims
   squeeze

Changing kind of array
======================
.. autosummary::
   :toctree: generated/

   asarray
   asanyarray
   asmatrix
   asfarray
   asfortranarray
   ascontiguousarray
   asarray_chkfinite
   asscalar
   require

Joining arrays
==============
.. autosummary::
   :toctree: generated/

   concatenate
   stack
   column_stack
   dstack
   hstack
   vstack

Splitting arrays
================
.. autosummary::
   :toctree: generated/

   split
   array_split
   dsplit
   hsplit
   vsplit

Tiling arrays
=============
.. autosummary::
   :toctree: generated/

   tile
   repeat

Adding and removing elements
============================
.. autosummary::
   :toctree: generated/

   delete
   insert
   append
   resize
   trim_zeros
   unique

Rearranging elements
====================
.. autosummary::
   :toctree: generated/

   fliplr
   flipud
   reshape
   roll
   rot90
